@@ -6,6 +6,11 @@
 //        to an arena, so check to make sure we copy the items out and don't store the
 //        the item with the arena in it.
 
+#ifndef NSS_NSS_MODULE_H
+#define NSS_NSS_MODULE_H
+
+#define NSS_NSS_MODULE_NAME "nss"
+
 /* NSPR header files */
 #undef HAVE_LONG_LONG           /* FIXME: both Python.h and nspr.h define HAVE_LONG_LONG  */
 #include <stdbool.h>
@@ -47,6 +52,7 @@ typedef struct {
     PyObject_HEAD
     SECItem item;
     SECItemKind kind;
+    int buffer_exports;
 } SecItem;
 
 #define SecItem_GET_SIZE(op)  (Py_ssize_t)(op->item.len)
@@ -488,13 +494,13 @@ import_nspr_nss_c_api(void)
         return -1;
     }
 
-    if (!(PyCObject_Check(c_api_object))) {
+    if (!(PyCapsule_CheckExact(c_api_object))) {
         Py_DECREF(c_api_object);
         Py_DECREF(module);
         return -1;
     }
 
-    if ((api = PyCObject_AsVoidPtr(c_api_object)) == NULL) {
+    if ((api = PyCapsule_GetPointer(c_api_object, "_C_API")) == NULL) {
         Py_DECREF(c_api_object);
         Py_DECREF(module);
         return -1;
@@ -507,3 +513,4 @@ import_nspr_nss_c_api(void)
 }
 
 #endif /* NSS_NSS_MODULE */
+#endif /* NSS_NSS_MODULE_H */
