@@ -1,4 +1,4 @@
-#!/usr/bin/python
+from __future__ import absolute_import
 
 import argparse
 import atexit
@@ -10,6 +10,7 @@ import subprocess
 import sys
 from string import Template
 import tempfile
+import six
 
 #-------------------------------------------------------------------------------
 logger = None
@@ -43,7 +44,8 @@ def run_cmd(cmd_args, input=None):
         p = subprocess.Popen(cmd_args,
                              stdin=subprocess.PIPE,
                              stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE)
+                             stderr=subprocess.PIPE,
+                             universal_newlines=True)
         stdout, stderr = p.communicate(input)
         returncode = p.returncode
         if returncode != 0:
@@ -94,13 +96,13 @@ def init_noise_file(options):
         os.write(fd, random_data)
         os.close(fd)
     else:
-        with open(options.noise_filename, 'w') as f:
+        with open(options.noise_filename, 'wb') as f:
             f.write(random_data)
     return
 
 def create_passwd_file(options):
     fd, options.passwd_filename = tempfile.mkstemp()
-    os.write(fd, options.db_passwd)
+    os.write(fd, options.db_passwd.encode('utf-8'))
     os.close(fd)
 
 
@@ -348,7 +350,7 @@ def get_system_fips_enabled():
         return True
     else:
         return False
-        
+
 
 def get_db_fips_enabled(db_name):
     cmd_args = ['/usr/bin/modutil',
@@ -364,7 +366,7 @@ def get_db_fips_enabled(db_name):
             return parse_fips_enabled(e.stdout)
         else:
             raise
-        
+
 def set_fips_mode(options):
     if options.fips:
         state = 'true'
@@ -502,13 +504,13 @@ def setup_certs(args):
     # This is ugly because argparse does not expose an API which permits iterating over
     # the contents of options nor a way to get the options as a dict, ugh :-(
     # So we access options.__dict__ directly.
-    for key in options.__dict__.keys():
+    for key in list(options.__dict__.keys()):
         # Assume options never begin with underscore
         if key.startswith('_'):
             continue
         value = getattr(options, key)
         # Can't substitue on non-string values
-        if not isinstance(value, basestring):
+        if not isinstance(value, six.string_types):
             continue
         # Don't bother trying to substitute if $ substitution character isn't present
         if '$' not in value:
